

*------------------------------------------------------------------------------*
//          限选条款设置中的股东角色与条款治理效果研究                        //
*-------------------------------------------------------------------------------*


/*注：该文包括公司-年度层面的分析和公司-年度-董事层面的分析
      此程序1为公司-年度层面分析的do-file
*/


use 数据1.dta,clear


***描述性统计
**附表3 主要变量描述性统计
logout, dec(4) save(mytable) excel replace: tabstat     ///  
limit L_takeover L_lntakeover L_top1 L_relative_control L_chairman_appointed L_exist_5 L_exist_10 ///
L_number_over5 L_number_over10 L_size L_state L_leverage L_age L_turnover L_growth L_lnPE1 ///
L_duality L_boardsize L_independence, stats(n mean sd min p50 max) c(s) format(%12.4f)



**************************************************************
**************限选条款设置中的股东角色分析********************
**************************************************************

global xlist L_size L_state L_leverage L_age L_duality L_boardsize L_turnover L_growth  ///
L_independence L_lnPE1 i.year i.industry_id 


***1.均值差异检验

*附表4
ttable3 limit,by(L_takeover) format(%8.4f)
ttable3 limit,by(L_relative_control) format(%8.4f)
ttable3 limit,by(L_chairman_appointed) format(%8.4f)
ttable3 limit,by(L_exist_5) format(%8.4f)  
ttable3 limit,by(L_exist_10) format(%8.4f)  

***2.多元回归分析

*表1 第一大股东影响限选条款设置——多元回归结果
xi:logit limit L_takeover $xlist ,vce(cluster id)
est store m1
xi:logit limit L_lntakeover $xlist ,vce(cluster id)
est store m2
xi:logit limit L_top1 $xlist ,vce(cluster id)
est store m3
xi:logit limit L_relative_control $xlist ,vce(cluster id)
est store m4
xi:logit limit L_chairman_appointed $xlist ,vce(cluster id)
est store m5
xi:logit limit L_takeover L_top1 L_chairman_appointed $xlist ,vce(cluster id)
est store m6
outreg2 [m1 m2 m3 m4 m5 m6] using sheet1, excel replace  ///
dec(4) keep(L_takeover L_lntakeover L_top1 L_relative_control L_chairman_appointed) ///
addtext(Year FE, Yes, Industry FE, Yes, Controls, Yes) addstat(Pseudo R-squared, `e(r2_p)')
est clear

*表2 其他大股东影响限选条款设置——多元回归结果  
xi:logit limit L_exist_5 L_top1 L_takeover L_chairman_appointed $xlist ,vce(cluster id)          //OK
est store m1
xi:logit limit L_exist_10 L_top1 L_takeover L_chairman_appointed $xlist ,vce(cluster id)          //OK
est store m2 
xi:logit limit L_number_over5 L_top1 L_takeover L_chairman_appointed $xlist ,vce(cluster id)          //OK
est store m3
xi:logit limit L_number_over10 L_top1 L_takeover L_chairman_appointed $xlist ,vce(cluster id)          //OK
est store m4
outreg2 [m1 m2 m3 m4] using sheet2, excel replace  ///
dec(4) keep(L_exist_5 L_exist_10 L_number_over5 L_number_over10 L_top1 L_takeover L_chairman_appointed) ///
sortvar(L_exist_5 L_exist_10 L_number_over5 L_number_over10 L_top1 L_takeover L_chairman_appointed)  ///
addtext(Year FE, Yes, Industry FE, Yes, Controls, Yes) addstat(Pseudo R-squared, `e(r2_p)')
est clear

**用30%和20%替换1/3持股比例开展稳健性检验
gen L_percent30=1 if L_top1>=0.3
replace L_percent30=0 if L_percent30==.
gen L_percent20=1 if L_top1>=0.2
replace L_percent20=0 if L_percent20==.

*附表11 第一大股东持股比例与限选条款设置——均值差异检验
ttable3 limit,by(L_percent30) format(%8.4f)
ttable3 limit,by(L_percent20) format(%8.4f)

*附表12 第一大股东持股比例与限选条款设置——多元回归
xi:logit limit L_percent30 $xlist ,vce(cluster id)
est store m1
xi:logit limit L_percent20 $xlist ,vce(cluster id)
est store m2
outreg2 [m1 m2] using sheet12_attached, excel replace  ///
dec(4) keep(L_percent30 L_percent20) ///
addtext(Controls, Yes, Year FE, Yes, Industry FE, Yes) addstat(Pseudo R-squared, `e(r2_p)')
est clear


***3.内生性问题控制

**工具变量法

*附表5 第一大股东影响限选条款设置——工具变量法控制内生性问题
xi:ivprobit limit  $xlist (L_takeover=L_takeover_average) ,twostep first 
est store m1
xi:ivprobit limit  $xlist (L_top1=L_lnholder) ,twostep first 
est store m2
xi:ivprobit limit  $xlist (L_chairman_appointed=L_lnholder) ,twostep first 
est store m3

*附表6 其他大股东影响限选条款设置——工具变量法控制内生性问题
xi:ivprobit limit  $xlist L_top1 L_takeover L_chairman_appointed (L_exist_5=L_lnholder) ,twostep first 
est store m1
xi:ivprobit limit  $xlist L_top1 L_takeover L_chairman_appointed (L_number_over5=L_lnholder) ,twostep first 
est store m2
xi:ivprobit limit  $xlist L_top1 L_takeover L_chairman_appointed (L_exist_10=L_lnholder) ,twostep first 
est store m3
xi:ivprobit limit  $xlist L_top1 L_takeover L_chairman_appointed (L_number_over10=L_lnholder) ,twostep first 
est store m4

**倾向得分匹配

psmatch2 limit L_size L_state L_leverage L_age L_duality L_boardsize L_turnover L_growth  ///
L_independence L_lnPE1 i.year i.industry_id ,outcome(roa1) n(2) ate ties logit common 

*附图1 匹配变量的标准化偏差图示
pstest L_size L_state L_leverage L_age L_duality L_boardsize L_turnover L_growth  ///
L_independence L_lnPE1  ,both graph

*附表7 围绕第一大股东影响限选条款设置开展的PSM检验
xi:logit limit L_takeover $xlist if _weight!=.,vce(cluster id)    //OK
est store m1
xi:logit limit L_lntakeover $xlist if _weight!=.,vce(cluster id)    //OK
est store m2
xi:logit limit L_top1 $xlist if _weight!=.,vce(cluster id)    //OK
est store m3
xi:logit limit L_relative_control $xlist if _weight!=.,vce(cluster id)    //OK
est store m4
xi:logit limit L_chairman_appointed $xlist if _weight!=.,vce(cluster id)    //OK
est store m5
outreg2 [m1 m2 m3 m4 m5] using sheet7_attached, excel replace  ///
dec(4) keep(L_takeover L_lntakeover L_top1 L_relative_control L_chairman_appointed) ///
addtext(Controls, Yes, Year FE, Yes, Industry FE, Yes) addstat(Pseudo R-squared, `e(r2_p)')
est clear

*附表8 围绕其他大股东影响限选条款设置开展的PSM检验
xi:logit limit L_exist_5 $xlist L_takeover L_top1 L_chairman_appointed if _weight!=.,vce(cluster id)    //OK
est store m1
xi:logit limit L_exist_10 $xlist L_takeover L_top1 L_chairman_appointed if _weight!=.,vce(cluster id)    //OK
est store m2
xi:logit limit L_number_over5 $xlist L_takeover L_top1 L_chairman_appointed if _weight!=.,vce(cluster id)    //OK
est store m3
xi:logit limit L_number_over10 $xlist L_takeover L_top1 L_chairman_appointed if _weight!=.,vce(cluster id)    //OK
est store m4
outreg2 [m1 m2 m3 m4] using sheet8_attached, excel replace  ///
dec(4) keep(L_exist_5 L_exist_10 L_number_over5 L_number_over10 L_takeover L_top1 L_chairman_appointed) ///
addtext(Controls, Yes, Year FE, Yes, Industry FE, Yes) addstat(Pseudo R-squared, `e(r2_p)')
est clear





**************************************************************
**************限选条款设置的公司治理效果分析******************
**************************************************************

global xlist L_size L_state L_leverage L_age L_duality L_boardsize L_turnover L_growth  ///
L_independence L_lnPE1 L_top1 L_chairman_appointed i.year i.industry_id  

***1.限选条款具有防御作用吗？

*表3
xi:reg D_lntakeover L_limit $xlist ,vce(cluster id)
est store m1
xi:logit dim_chairman L_limit $xlist L_takeover L_exist_5, vce(cluster id)
est store m2
xi:logit dim_ceo L_limit $xlist L_takeover L_exist_5, vce(cluster id)
est store m3
xi:logit dim_either L_limit $xlist L_takeover L_exist_5, vce(cluster id)
est store m4
outreg2 [m1 m2 m3 m4] using sheet3, excel replace  ///
dec(4) keep(L_limit) addtext(Controls, Yes, Year FE, Yes, Industry FE, Yes) ///
addstat(Pseudo R-squared, `e(r2_p)')
est clear

***2.限选条款会加剧股东权利分配不公吗？
*注：见程序2



***3.限选条款会引发哪些代理问题？

global xlist L_size L_state L_leverage L_age L_duality L_boardsize L_turnover L_growth  ///
L_independence L_lnPE1 L_top1 L_exist_5 L_chairman_appointed L_takeover i.year i.industry_id 

*表6 公司治理效果：限选条款引发的代理成本
*超额薪酬1
gen L_roa1_limit=L_roa1*L_limit
xi:reg lnsalary_notindepen L_limit $xlist ,vce(cluster id)
est store m1
xi:reg lnsalary_notindepen L_roa1 L_limit L_roa1_limit $xlist ,vce(cluster id)
est store m2
*超额薪酬2
xi:reg lnsalary_notindepen L_size L_lnrevenue L_Q return L_return roa1 L_roa1 L_age i.year i.industry_id i.province_id ,vce(cluster id)
predict e,re
rename e over_salary
xi:reg over_salary L_limit $xlist ,vce(cluster id)
est store m3
*在职消费
xi:reg perk2 L_limit $xlist ,vce(cluster id)
est store m4
outreg2 [m1 m2 m3 m4] using sheet6, excel replace  ///
dec(4) keep(L_limit L_roa1 L_roa1_limit) addtext(Year FE, Yes, Industry FE, Yes, Controls, Yes) 
est clear

*附表9 公司治理效果：限选条款设置对公司绩效的影响
xi:reg roa1 L_limit $xlist ,vce(cluster id)
est store m1
xi:reg roa1_adj L_limit $xlist ,vce(cluster id)
est store m2
xi:reg roa1_3years L_limit $xlist ,vce(cluster id)
est store m3
xi:reg ebit_asset L_limit $xlist ,vce(cluster id)
est store m4
xi:reg ebit_asset_adj L_limit $xlist ,vce(cluster id)
est store m5
xi:reg ebit_asset_3years L_limit $xlist ,vce(cluster id)
est store m6
outreg2 [m1 m2 m3 m4 m5 m6] using sheet9_attached, excel replace  ///
dec(4) keep(L_limit) addtext(Controls, Yes, Year FE, Yes, Industry FE, Yes) 
est clear




**************************************************************
***************************拓展性研究*************************
**************************************************************

global xlist L_size L_state L_leverage L_age L_duality L_boardsize L_turnover L_growth  ///
L_independence L_lnPE1 L_top1 L_exist_5 L_chairman_appointed i.year i.industry_id 
*表7 限制改选时间不同的限选条款的防御意味和防御效果差异
xi:logit limit_hj L_takeover $xlist if limit==0|limit_hj==1,vce(cluster id)
est store m1
xi:logit limit_nothj L_takeover $xlist if limit==0|limit_nothj==1,vce(cluster id)
est store m2
xi:logit limit_eachyear L_takeover $xlist if limit==0|limit_eachyear==1,vce(cluster id)
est store m3
xi:reg D_lntakeover L_limit_hj $xlist if L_limit==0|L_limit_hj==1,vce(cluster id)
est store m4
xi:reg D_lntakeover L_limit_nothj $xlist if L_limit==0|L_limit_nothj==1,vce(cluster id)
est store m5
xi:reg D_lntakeover L_limit_eachyear $xlist if L_limit==0|L_limit_eachyear==1,vce(cluster id)
est store m6
outreg2 [m1 m2 m3 m4 m5 m6] using sheet7, excel replace  ///
dec(4) keep(L_takeover L_limit_hj L_limit_nothj L_limit_eachyear) addtext(Year FE, Yes, Industry FE, Yes, Controls, Yes) 
est clear

*表8 不同类型的限选条款对第一大股东及其关联股东委派董事的“偏袒”保护
*注；见程序2












